StorageExt

Trait StorageExt 

pub trait StorageExt<C: Mirrored> {
    // Required method
    fn read_events(
        &self,
        reader: &mut ReaderId<C::Event>,
    ) -> EventIterator<'_, C::Event>;
}
Extension methods for Storage to help read events from MirroredStorage.

Required Methods

fn read_events( &self, reader: &mut ReaderId<C::Event>, ) -> EventIterator<'_, C::Event>

Read insertion and removal events from the event channel.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, C, S, D> StorageExt<C> for Storage<'a, C, D>
where C: Mirrored + Component<Storage = MirroredStorage<C, S>>, S: UnprotectedStorage<C> + Any + Send + Sync, D: Deref<Target = MaskedStorage<C>>,

Source

fn read_events( &self, reader: &mut ReaderId<C::Event>, ) -> EventIterator<'_, C::Event>

Implementors